@@ -1,5 +1,3 @@
-from typing import Optional
-
 from fastapi import Cookie, Depends
 
 from fief.crypto.token import get_token_hash
@@ -10,11 +8,11 @@ from fief.settings import settings
 
 
 async def get_session_token(
-    token: Optional[str] = Cookie(None, alias=settings.session_cookie_name),
+    token: str | None = Cookie(None, alias=settings.session_cookie_name),
     repository: SessionTokenRepository = Depends(
         get_workspace_repository(SessionTokenRepository)
     ),
-) -> Optional[SessionToken]:
+) -> SessionToken | None:
     if token is not None:
         token_hash = get_token_hash(token)
         return await repository.get_by_token(token_hash)
