@@ -44,7 +44,13 @@ class APIErrorCode(str, Enum):
     ROLE_UPDATE_NOT_EXISTING_PERMISSION = "ROLE_UPDATE_NOT_EXISTING_PERMISSION"
 
     TENANT_CREATE_NOT_EXISTING_THEME = "TENANT_CREATE_NOT_EXISTING_THEME"
+    TENANT_CREATE_NOT_EXISTING_OAUTH_PROVIDER = (
+        "TENANT_CREATE_NOT_EXISTING_OAUTH_PROVIDER"
+    )
     TENANT_UPDATE_NOT_EXISTING_THEME = "TENANT_UPDATE_NOT_EXISTING_THEME"
+    TENANT_UPDATE_NOT_EXISTING_OAUTH_PROVIDER = (
+        "TENANT_UPDATE_NOT_EXISTING_OAUTH_PROVIDER"
+    )
 
     USER_PERMISSION_CREATE_NOT_EXISTING_PERMISSION = (
         "USER_PERMISSION_CREATE_NOT_EXISTING_PERMISSION"
