@@ -1,8 +1,8 @@
 from datetime import datetime, timezone
 
 from pydantic import UUID4
-from sqlalchemy import Column, ForeignKey, String, Text
-from sqlalchemy.orm import relationship
+from sqlalchemy import ForeignKey, String, Text
+from sqlalchemy.orm import Mapped, mapped_column, relationship
 from sqlalchemy.sql.schema import UniqueConstraint
 
 from fief.crypto.encryption import FernetEngine, StringEncryptedType
@@ -18,30 +18,34 @@ class OAuthAccount(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     __tablename__ = "oauth_accounts"
     __table_args__ = (UniqueConstraint("oauth_provider_id", "user_id"),)
 
-    access_token: str = Column(
+    access_token: Mapped[str] = mapped_column(
         StringEncryptedType(Text, settings.encryption_key, FernetEngine), nullable=False
     )
-    expires_at: datetime | None = Column(TIMESTAMPAware(timezone=True), nullable=True)
-    refresh_token: str | None = Column(
+    expires_at: Mapped[datetime | None] = mapped_column(
+        TIMESTAMPAware(timezone=True), nullable=True
+    )
+    refresh_token: Mapped[str | None] = mapped_column(
         StringEncryptedType(Text, settings.encryption_key, FernetEngine), nullable=True
     )
-    account_id: str = Column(String(length=512), index=True, nullable=False)
-    account_email: str | None = Column(String(length=512), nullable=True)
+    account_id: Mapped[str] = mapped_column(
+        String(length=512), index=True, nullable=False
+    )
+    account_email: Mapped[str | None] = mapped_column(String(length=512), nullable=True)
 
-    oauth_provider_id: UUID4 = Column(
+    oauth_provider_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(OAuthProvider.id, ondelete="CASCADE"), nullable=False
     )
-    oauth_provider: OAuthProvider = relationship("OAuthProvider", lazy="joined")
+    oauth_provider: Mapped[OAuthProvider] = relationship("OAuthProvider", lazy="joined")
 
-    user_id: UUID4 | None = Column(
+    user_id: Mapped[UUID4 | None] = mapped_column(
         GUID, ForeignKey(User.id, ondelete="CASCADE"), nullable=True
     )
-    user: User | None = relationship("User", lazy="joined")
+    user: Mapped[User | None] = relationship("User", lazy="joined")
 
-    tenant_id: UUID4 = Column(
+    tenant_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(Tenant.id, ondelete="CASCADE"), nullable=False
     )
-    tenant: Tenant = relationship("Tenant")
+    tenant: Mapped[Tenant] = relationship("Tenant")
 
     def is_expired(self) -> bool:
         return self.expires_at is not None and self.expires_at < datetime.now(
